==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/WebTabDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebTabDescription } from "./WebTabDescription";
/**
 * @hidden
 */
export let WebTabDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebTabDescriptionMetadata extends Base {
        static b(a) {
            if (WebTabDescriptionMetadata.a == null) {
                WebTabDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebTabDescriptionMetadata.c(WebTabDescriptionMetadata.a);
            }
            if (a.k(WebTabDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebTabDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:Tab");
            a.item("__tagNameWC", "String:igc-tab");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("Panel", "String");
            a.item("Selected", "Boolean");
            a.item("Disabled", "Boolean");
        }
        static d(a) {
            WebTabDescriptionMetadata.b(a);
            a.ad("WebTab", () => new WebTabDescription());
            a.ac("WebTab", WebTabDescriptionMetadata.a);
        }
    }
    WebTabDescriptionMetadata.$t = markType(WebTabDescriptionMetadata, 'WebTabDescriptionMetadata');
    WebTabDescriptionMetadata.a = null;
    return WebTabDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/WebTabDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebTabDescription } from "./WebTabDescription";
/**
 * @hidden
 */
export let WebTabDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebTabDescriptionMetadata extends Base {
        static b(a) {
            if (WebTabDescriptionMetadata.a == null) {
                WebTabDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebTabDescriptionMetadata.c(WebTabDescriptionMetadata.a);
            }
            if (a.k(WebTabDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebTabDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:Tab");
            a.item("__tagNameWC", "String:igc-tab");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("Label", "String");
            a.item("Selected", "Boolean");
            a.item("Disabled", "Boolean");
        }
        static d(a) {
            WebTabDescriptionMetadata.b(a);
            a.ae("WebTab", () => new WebTabDescription());
            a.ad("WebTab", WebTabDescriptionMetadata.a);
        }
    }
    WebTabDescriptionMetadata.$t = markType(WebTabDescriptionMetadata, 'WebTabDescriptionMetadata');
    WebTabDescriptionMetadata.a = null;
    return WebTabDescriptionMetadata;
})();
